# Roadmap

Some of these items can be achieved by combining existing tools, but others may require us to build bespoke software solutions. See [[build-vs-assemble]] to understand trade-offs between these approaches. If a feature can be implemented by contributing to [[recipes]], it should.

## In progress

Items that are already being worked on. Roadmap items in this stage should have an owner.

## High priority

Items we plan on working next. Items in this stage don't need to have an owner, but before we start working on them should have enough specification that they can be picked up and worked on without having to seek consensus.

If you want to pick up work in this category, you should have a plan on how long the implementation will approximately take so we don't block progress by sitting on high priority issues.

## Backlog

Everything else, categorised into themes. Just because something is on this list doesn't mean it'll get done. If you're interested in working on items in this category, check the [[contribution-guide]] for how to get started.

If a roadmap item is a stub, **consider** opening a [GitHub issue](https://github.com/foambubble/foam/issues) to start a conversation to avoid situations where the implementation does not fit long term vision and roadmap. _Note that this is optional. The only centralised governance in Foam is to decide what ends up in the official [template](https://github.com/foambubble/foam-template), [documentation](https://github.com/foambubble/foam) and [extension](https://github.com/foambubble/foam/tree/master/packages/foam-vscode). You are free to build whatever you want for yourself, and we'd love if you shared it with us, but you are by no means obligated to do so!_

**When creating GitHub issues to discuss roadmap items, link them here.**

### Known issues

- [[improve-default-workspace-settings]]
  - Discussion: [foam#270](https://github.com/foambubble/foam/issues/270)
- Improve [[git-integration]]
- Fix [[wiki-links]] compatibility issues
- Simplify [[foam-file-format]]

### Core features

- [[renaming-files]]
- [[unlinked-references]]
- [[block-references]]
- [[improved-backlinking]]
  - UX: [[make-backlinks-more-prominent]]
- [[materialized-backlinks]]
- [[automatic-git-syncing]]
- [[git-flows-for-teams]]
- [[user-settings]]
- [[link-reference-definitions]]
- [[predefined-user-snippets]]

### Publishing

- [[officially-support-alternative-templates]]
- [[improved-static-site-generation]]
- [[mdx-by-default]]
- [[search-in-published-workspace]]
- [[graph-in-published-workspace]]
  - Discussion: [foam#58](https://github.com/foambubble/foam/issues/58)
- [[linking-between-published-workspaces]]
  - Discussion: [foam#59](https://github.com/foambubble/foam/issues/59)
- [[publishing-permissions]]

### Platforms

- [[cli]]
- [[mobile-apps]]
- [[packaged-desktop-app]]
- [[web-editor]]

### Migration

The community is working on a number of automated scripts to help you migrate to Foam. The main work of developing such a method involves exporting your notes, converting them to the Markdown format, and then making sure that the links between notes (if you had those) still work.

- [[migrating-from-roam]]
  - Discussion: [foam#55](https://github.com/foambubble/foam/issues/55)
- [[migrating-from-obsidian]]
  - Discussion: [foam#46](https://github.com/foambubble/foam/issues/46)
- [[migrating-from-onenote]]
  - Discussion: [foam#151](https://github.com/foambubble/foam/issues/151)
- _Migration from other tools..._

### Integration

- _Integrations to third party tools_...

### Wild ideas

- [[foam-linter]]
- [[refactoring-via-language-server-protocol]]

[//begin]: # "Autogenerated link references for markdown compatibility"
[build-vs-assemble]: build-vs-assemble.md "Build vs Assemble"
[recipes]: ../recipes/recipes.md "Recipes"
[contribution-guide]: ../contribution-guide.md "Contribution Guide"
[git-integration]: ../features/git-integration.md "Git Integration"
[wiki-links]: ../wiki-links.md "Wiki Links"
[foam-file-format]: foam-file-format.md "Foam File Format"
[unlinked-references]: unlinked-references.md "Unlinked references (stub)"
[make-backlinks-more-prominent]: ../recipes/make-backlinks-more-prominent.md "Make Backlinks More Prominent"
[materialized-backlinks]: materialized-backlinks.md "Materialized Backlinks (stub)"
[automatic-git-syncing]: ../recipes/automatic-git-syncing.md "Automatically Sync with Git"
[link-reference-definitions]: ../features/link-reference-definitions.md "Link Reference Definitions"
[predefined-user-snippets]: ../recipes/predefined-user-snippets.md "Pre-defined User Snippets"
[mdx-by-default]: mdx-by-default.md "MDX by Default(stub)"
[publishing-permissions]: publishing-permissions.md "Publishing Permissions(stub)"
[cli]: ../features/cli.md "Command Line Interface"
[migrating-from-roam]: ../recipes/migrating-from-roam.md "Migrating from Roam (stub)"
[migrating-from-obsidian]: ../recipes/migrating-from-obsidian.md "Migrating from Obsidian (stub)"
[migrating-from-onenote]: ../recipes/migrating-from-onenote.md "Migrating from OneNote"
[//end]: # "Autogenerated link references"
